@@ -1,7 +1,6 @@
 from termcolor import colored
 from pusher import Pusher
 import pysher
-from dotenv import load_dotenv
 import os
 import json
 import random
@@ -10,9 +9,14 @@ import re
 
 
 from utils import welcome
+from utils import sign_up
+from utils import log_in
+from utils import close_app
+from utils import logged_in
+from utils import delete_User
 
-load_dotenv(dotenv_path='.env')
+#load_dotenv(dotenv_path='.env')
 
                 
 if __name__ == "__main__":
-    welcome()
+   welcome()
