@@ -121,7 +121,8 @@ class logged_in:
     user = None
     #self.user = log_in.__init__()
     #user = None
-    chatrooms = ["Python", "Java", "Php", "C", "Web", "Stacks", "General"]
+    chatrooms = ["sports", "general", "education", "health", "technology"]
+    #chatrooms = ["Python", "Java", "Php", "C", "Web", "Stacks", "General"]
     def __init__(self):
         print("\n")        
         print(colored("You're logged in   ", "blue"))
@@ -152,7 +153,6 @@ class logged_in:
         try:
             print("Please pres Ctrl+c at anytime to exit")        
             print(colored("Info! Available Rooms are %s" % str(self.chatrooms), "blue"))
-            print(self.chatrooms)
             chatroom = input(colored("Please select a Room: ", "green")).capitalize()
             if chatroom in self.chatrooms:
                 print("Please pres Ctrl+c at anytime to exit the Room")
